Method: MastermindRuby::ConsoleInterface#display_welcome_message
- Defined in:
- lib/mastermind_ruby/console_interface.rb
#display_welcome_message(playername) ⇒ Object
Method which is called when the game is initiated to display the game has been started Params:
playername-
the playername which was read before with :read_playername
38 39 40 41 42 |
# File 'lib/mastermind_ruby/console_interface.rb', line 38 def (playername) puts '-------- Mastermind Ruby Project -------' puts "Hello #{playername}, your code is generated!" puts "Avaliable Characters:\t#{MastermindRuby::Code::AVAILABLE_CHARACTERS.join("\t")}" end |